---
myst:
  html_meta:
    "description": "cs_dynamicpages Tutorials"
    "property=og:description": "cs_dynamicpages Tutorials"
    "property=og:title": "cs_dynamicpages Tutorials"
    "keywords": "Plone, cs_dynamicpages, tutorials"
---

# Tutorials

This part of the documentation contains tutorials.

> A tutorial is an experience that takes place under the guidance of a tutor.
> A tutorial is always learning-oriented.

```{seealso}
https://diataxis.fr/tutorials/
```

```{toctree}
:maxdepth: 2

first-dynamic-page
```
